@@ -5,9 +5,6 @@ from .baseshield import BaseShield
 
 
 class DummyShield(BaseShield):
-    def __init__(self) -> None:
-        pass
-
     def read(self) -> tuple[float]:
         ti = time.perf_counter()
 
@@ -17,7 +14,7 @@ class DummyShield(BaseShield):
         return pot, sensor
 
     def write(self, flag: int, actuator: float):
-        return self.saturate(actuator, self.actuator_bits)
+        return self.saturate_bits(actuator, self.actuator_bits)
 
     def open(self):
         return self
